.. image:: ../artwork/cicada.png
  :width: 200px
  :align: right

.. _anaconda-installation:

Anaconda Installation
=====================

Whether you’re new to Python or an old hand, we highly recommend installing
`Anaconda <https://www.continuum.io/downloads>`_. Anaconda conveniently
installs Python and other commonly used packages for scientific computing and
data science in your home directory, including all of Cicada's dependencies.

